==> haskell-hourglass-0.2.12-146-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hourglass.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hourglass
version:              0.2.12
visibility:           public
id:                   hourglass-0.2.12-LbKDGJQ7fkj6vMj9HeHCYz
key:                  hourglass-0.2.12-LbKDGJQ7fkj6vMj9HeHCYz
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-hourglass
synopsis:             simple performant time related library
description:
    Simple time library focusing on simple but powerful and performant API

    The backbone of the library are the Timeable and Time type classes.

    Each Timeable instances can be converted to type that has a Time instances,
    and thus are different representations of current time.

category:             Time
abi:                  b22af4788a48d34a15f7f7a0fa4924c5
exposed:              True
exposed-modules:
    Data.Hourglass Data.Hourglass.Compat Data.Hourglass.Epoch
    Data.Hourglass.Types System.Hourglass Time.Compat Time.System
    Time.Types

hidden-modules:
    Data.Hourglass.Time Data.Hourglass.Format Data.Hourglass.Diff
    Data.Hourglass.Local Data.Hourglass.Calendar Data.Hourglass.Zone
    Data.Hourglass.Internal Data.Hourglass.Utils
    Data.Hourglass.Internal.Unix

import-dirs:          /usr/lib/ghc-9.0.1/site-local/hourglass-0.2.12
library-dirs:         /usr/lib/ghc-9.0.1/site-local/hourglass-0.2.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/hourglass-0.2.12
hs-libraries:         HShourglass-0.2.12-LbKDGJQ7fkj6vMj9HeHCYz
depends:              base-4.15.0.0 deepseq-1.4.5.0
haddock-interfaces:   /usr/share/doc/haskell-hourglass/html/hourglass.haddock
haddock-html:         /usr/share/doc/haskell-hourglass/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hourglass-0.2.12-149-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hourglass.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hourglass
version:              0.2.12
visibility:           public
id:                   hourglass-0.2.12-B4ZP08MfadCCL3YfGxU969
key:                  hourglass-0.2.12-B4ZP08MfadCCL3YfGxU969
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-hourglass
synopsis:             simple performant time related library
description:
    Simple time library focusing on simple but powerful and performant API

    The backbone of the library are the Timeable and Time type classes.

    Each Timeable instances can be converted to type that has a Time instances,
    and thus are different representations of current time.

category:             Time
abi:                  d29407e5203573ae9d783d2fb6b4dde2
exposed:              True
exposed-modules:
    Data.Hourglass Data.Hourglass.Compat Data.Hourglass.Epoch
    Data.Hourglass.Types System.Hourglass Time.Compat Time.System
    Time.Types

hidden-modules:
    Data.Hourglass.Time Data.Hourglass.Format Data.Hourglass.Diff
    Data.Hourglass.Local Data.Hourglass.Calendar Data.Hourglass.Zone
    Data.Hourglass.Internal Data.Hourglass.Utils
    Data.Hourglass.Internal.Unix

import-dirs:          /usr/lib/ghc-9.0.1/site-local/hourglass-0.2.12
library-dirs:         /usr/lib/ghc-9.0.1/site-local/hourglass-0.2.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/hourglass-0.2.12
hs-libraries:         HShourglass-0.2.12-B4ZP08MfadCCL3YfGxU969
depends:              base-4.15.0.0 deepseq-1.4.5.0
haddock-interfaces:   /usr/share/doc/haskell-hourglass/html/hourglass.haddock
haddock-html:         /usr/share/doc/haskell-hourglass/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
